@@ -1,7 +1,7 @@
 package Bencher::Scenario::TextTableModules;
 
-our $DATE = '2015-12-17'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-12-19'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -96,6 +96,13 @@ our $scenario = {
                 Text::Table::Org::table(rows=>$table, header_row=>1);
             },
         },
+        {
+            module => 'Text::Table::CSV',
+            code => sub {
+                my ($table) = @_;
+                Text::Table::CSV::table(rows=>$table, header_row=>1);
+            },
+        },
         {
             module => 'Text::TabularDisplay',
             code => sub {
@@ -132,7 +139,7 @@ Bencher::Scenario::TextTableModules - Benchmark Perl text table modules
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::TextTableModules (from Perl distribution Bencher-Scenario-TextTableModules), released on 2015-12-17.
+This document describes version 0.03 of Bencher::Scenario::TextTableModules (from Perl distribution Bencher-Scenario-TextTableModules), released on 2015-12-19.
 
 =head1 SYNOPSIS
 
@@ -154,6 +161,8 @@ L<Text::Table::Tiny>
 
 L<Text::Table::Org>
 
+L<Text::Table::CSV>
+
 L<Text::TabularDisplay>
 
 =head1 HOMEPAGE
